==> beast-privilege-api-2.6.4-GS-20230109.064208-20-sources.jar: com/thebeastshop/privilege/vo/FrontGiftCampaignVO.java <==
package com.thebeastshop.privilege.vo;

import java.io.Serializable;
import java.util.Date;
import java.util.List;

public class FrontGiftCampaignVO implements Serializable {
    private Integer id; //赠品活动ID
    private String name; //活动名称
    private Date startDate; //开始时间
    private Date endDate; //结束时间
    private String remark; //备注
    private Integer status; //状态（1：使用 0：禁用）
    private String systemDefault; //系统默认条件
    private String orderChannelCode; //订单渠道，逗号分隔
    private String orderType; //订单类型，逗号分隔
    private String orderBusinessType; //订单业务类型，逗号分隔
    private String memberLevel; //会员等级，逗号分隔
    private Date orderStartDate; //下单开始时间
    private Date orderEndDate; //下单结束时间
    private Date payStartDate; //付款开始时间
    private Date payEndDate; //付款结束时间

    private Integer hasJoin; //入会情况 1：已入会 0：否
    private String giftQualification; //赠品资格，逗号分隔
    private String thirdPartyInterface; //第三方接口，逗号分隔
    private String orderRemark; //订单备注
    private Boolean isFuzzyMatch; //是否模糊匹配 1：是 0：否
    private Integer scope; //适用范围 1：全场 2：指定SKU
    private Integer giftWay; //赠送方式 1：全部赠送 2：顺序赠送 3：随机N件
    private Integer randomNum; //随机几件
    private Integer totalNum; //赠送总量
    private Integer singleLimit; //单用户限赠 1：不限制 2：限赠1次
    private Integer giftCondition; //赠送条件 1：按金额（单订单） 2：按件数（单订单）3：按金额（按用户累计）4：按金额（按支付时间累计）
    private Integer stepRule; //阶梯规则 1：参与所有阶梯 2：只参与最高阶梯
    private Integer createUserId;
    private String createUserName;
    private Date createTime;
    private Date updateTime;

    //适用SKU
    private List<String> includeSkuCodes;
    //排除SKU
    private List<String> excludeSkuCodes;
    //资格ID
    private List<Integer> giftQualificationIds;
    //资格对象
    private List<GiftCampaignQualificationVO> giftCampaignQualificationVOList;
    //阶梯SKU信息
    private List<GiftCampaignRuleSkuVO> giftCampaignRuleSkuVOList;

    public Integer getId() {
        return id;
    }

    public void setId(Integer id) {
        this.id = id;
    }

    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }

    public Date getStartDate() {
        return startDate;
    }

    public void setStartDate(Date startDate) {
        this.startDate = startDate;
    }

    public Date getEndDate() {
        return endDate;
    }

    public void setEndDate(Date endDate) {
        this.endDate = endDate;
    }

    public String getRemark() {
        return remark;
    }

    public void setRemark(String remark) {
        this.remark = remark;
    }

    public Integer getStatus() {
        return status;
    }

    public void setStatus(Integer status) {
        this.status = status;
    }

    public String getSystemDefault() {
        return systemDefault;
    }

    public void setSystemDefault(String systemDefault) {
        this.systemDefault = systemDefault;
    }

    public String getOrderChannelCode() {
        return orderChannelCode;
    }

    public void setOrderChannelCode(String orderChannelCode) {
        this.orderChannelCode = orderChannelCode;
    }

    public String getOrderType() {
        return orderType;
    }

    public void setOrderType(String orderType) {
        this.orderType = orderType;
    }

    public String getOrderBusinessType() {
        return orderBusinessType;
    }

    public void setOrderBusinessType(String orderBusinessType) {
        this.orderBusinessType = orderBusinessType;
    }

    public String getMemberLevel() {
        return memberLevel;
    }

    public void setMemberLevel(String memberLevel) {
        this.memberLevel = memberLevel;
    }

    public Date getOrderStartDate() {
        return orderStartDate;
    }

    public void setOrderStartDate(Date orderStartDate) {
        this.orderStartDate = orderStartDate;
    }

    public Date getOrderEndDate() {
        return orderEndDate;
    }

    public void setOrderEndDate(Date orderEndDate) {
        this.orderEndDate = orderEndDate;
    }

    public Date getPayStartDate() {
        return payStartDate;
    }

    public void setPayStartDate(Date payStartDate) {
        this.payStartDate = payStartDate;
    }

    public Date getPayEndDate() {
        return payEndDate;
    }

    public void setPayEndDate(Date payEndDate) {
        this.payEndDate = payEndDate;
    }


    public Integer getHasJoin() {
        return hasJoin;
    }

    public void setHasJoin(Integer hasJoin) {
        this.hasJoin = hasJoin;
    }


    public String getGiftQualification() {
        return giftQualification;
    }

    public void setGiftQualification(String giftQualification) {
        this.giftQualification = giftQualification;
    }

    public String getThirdPartyInterface() {
        return thirdPartyInterface;
    }

    public void setThirdPartyInterface(String thirdPartyInterface) {
        this.thirdPartyInterface = thirdPartyInterface;
    }

    public String getOrderRemark() {
        return orderRemark;
    }

    public void setOrderRemark(String orderRemark) {
        this.orderRemark = orderRemark;
    }

    public Boolean getFuzzyMatch() {
        return isFuzzyMatch;
    }

    public void setFuzzyMatch(Boolean fuzzyMatch) {
        isFuzzyMatch = fuzzyMatch;
    }

    public Integer getScope() {
        return scope;
    }

    public void setScope(Integer scope) {
        this.scope = scope;
    }

    public Integer getGiftWay() {
        return giftWay;
    }

    public void setGiftWay(Integer giftWay) {
        this.giftWay = giftWay;
    }

    public Integer getRandomNum() {
        return randomNum;
    }

    public void setRandomNum(Integer randomNum) {
        this.randomNum = randomNum;
    }

    public Integer getTotalNum() {
        return totalNum;
    }

    public void setTotalNum(Integer totalNum) {
        this.totalNum = totalNum;
    }

    public Integer getSingleLimit() {
        return singleLimit;
    }

    public void setSingleLimit(Integer singleLimit) {
        this.singleLimit = singleLimit;
    }

    public Integer getGiftCondition() {
        return giftCondition;
    }

    public void setGiftCondition(Integer giftCondition) {
        this.giftCondition = giftCondition;
    }

    public Integer getStepRule() {
        return stepRule;
    }

    public void setStepRule(Integer stepRule) {
        this.stepRule = stepRule;
    }

    public Integer getCreateUserId() {
        return createUserId;
    }

    public void setCreateUserId(Integer createUserId) {
        this.createUserId = createUserId;
    }

    public String getCreateUserName() {
        return createUserName;
    }

    public void setCreateUserName(String createUserName) {
        this.createUserName = createUserName;
    }

    public Date getCreateTime() {
        return createTime;
    }

    public void setCreateTime(Date createTime) {
        this.createTime = createTime;
    }

    public Date getUpdateTime() {
        return updateTime;
    }

    public void setUpdateTime(Date updateTime) {
        this.updateTime = updateTime;
    }

    public List<String> getIncludeSkuCodes() {
        return includeSkuCodes;
    }

    public void setIncludeSkuCodes(List<String> includeSkuCodes) {
        this.includeSkuCodes = includeSkuCodes;
    }

    public List<String> getExcludeSkuCodes() {
        return excludeSkuCodes;
    }

    public void setExcludeSkuCodes(List<String> excludeSkuCodes) {
        this.excludeSkuCodes = excludeSkuCodes;
    }

    public List<Integer> getGiftQualificationIds() {
        return giftQualificationIds;
    }

    public void setGiftQualificationIds(List<Integer> giftQualificationIds) {
        this.giftQualificationIds = giftQualificationIds;
    }

    public List<GiftCampaignQualificationVO> getGiftCampaignQualificationVOList() {
        return giftCampaignQualificationVOList;
    }

    public void setGiftCampaignQualificationVOList(List<GiftCampaignQualificationVO> giftCampaignQualificationVOList) {
        this.giftCampaignQualificationVOList = giftCampaignQualificationVOList;
    }

    public List<GiftCampaignRuleSkuVO> getGiftCampaignRuleSkuVOList() {
        return giftCampaignRuleSkuVOList;
    }

    public void setGiftCampaignRuleSkuVOList(List<GiftCampaignRuleSkuVO> giftCampaignRuleSkuVOList) {
        this.giftCampaignRuleSkuVOList = giftCampaignRuleSkuVOList;
    }
}

==> beast-privilege-api-3.0.11-GS-20250910.083545-17-sources.jar: com/thebeastshop/privilege/vo/FrontGiftCampaignVO.java <==
package com.thebeastshop.privilege.vo;

import java.io.Serializable;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;

public class FrontGiftCampaignVO implements Serializable {
    private Integer id; //赠品活动ID
    private String name; //活动名称
    private Date startDate; //开始时间
    private Date endDate; //结束时间
    private String remark; //备注
    private Integer status; //状态（1：使用 0：禁用）
    private String systemDefault; //系统默认条件
    private String orderChannelCode; //订单渠道，逗号分隔
    private String orderType; //订单类型，逗号分隔
    private String orderBusinessType; //订单业务类型，逗号分隔
    private String memberLevel; //会员等级，逗号分隔
    private Date orderStartDate; //下单开始时间
    private Date orderEndDate; //下单结束时间
    private Date payStartDate; //付款开始时间
    private Date payEndDate; //付款结束时间

    private Integer hasJoin; //入会情况 1：已入会 0：否
    private String giftQualification; //赠品资格，逗号分隔
    private String thirdPartyInterface; //第三方接口，逗号分隔
    private String orderRemark; //订单备注
    private Boolean isFuzzyMatch; //是否模糊匹配 1：是 0：否
    private Integer scope; //适用范围 1：全场 2：指定SKU
    private Integer giftWay; //赠送方式 1：全部赠送 2：顺序赠送 3：随机N件 4：特殊逻辑
    private Integer randomNum; //随机几件
    private Integer totalNum; //赠送总量
    private Integer singleLimit; //单用户限赠 1：不限制 2：限赠1次
    private Integer giftCondition; //赠送条件 1：按金额（单订单） 2：按件数（单订单）3：按金额（按用户累计）4：按金额（按支付时间累计）
    private Integer stepRule; //阶梯规则 1：参与所有阶梯 2：只参与最高阶梯
    private Integer createUserId;
    private String createUserName;
    private Date createTime;
    private Date updateTime;

    private String giftWayText;  //备注

    private Integer sendFinishStop; //送完即止 0否,1是

    private Integer stepAmountCompute; //阶梯金额计算 1：计算适用商品金额 2：计算整单金额

    private String otherCondition;//“1”：渠道首单

    private String specialCondition;//特殊条件

    //适用SKU
    private List<GiftCampaignConditionSkuVO> includeSkuCodes = new ArrayList<>();
    //排除SKU
    private List<GiftCampaignConditionSkuVO> excludeSkuCodes  = new ArrayList<>();
    //资格ID
    private List<Integer> giftQualificationIds  = new ArrayList<>();
    //资格对象
    private List<GiftCampaignQualificationVO> giftCampaignQualificationVOList  = new ArrayList<>();
    //阶梯SKU信息
    private List<GiftCampaignRuleSkuVO> giftCampaignRuleSkuVOList  = new ArrayList<>();

    public Integer getId() {
        return id;
    }

    public void setId(Integer id) {
        this.id = id;
    }

    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }

    public Date getStartDate() {
        return startDate;
    }

    public void setStartDate(Date startDate) {
        this.startDate = startDate;
    }

    public Date getEndDate() {
        return endDate;
    }

    public void setEndDate(Date endDate) {
        this.endDate = endDate;
    }

    public String getRemark() {
        return remark;
    }

    public void setRemark(String remark) {
        this.remark = remark;
    }

    public Integer getStatus() {
        return status;
    }

    public void setStatus(Integer status) {
        this.status = status;
    }

    public String getSystemDefault() {
        return systemDefault;
    }

    public void setSystemDefault(String systemDefault) {
        this.systemDefault = systemDefault;
    }

    public String getOrderChannelCode() {
        return orderChannelCode;
    }

    public void setOrderChannelCode(String orderChannelCode) {
        this.orderChannelCode = orderChannelCode;
    }

    public String getOrderType() {
        return orderType;
    }

    public void setOrderType(String orderType) {
        this.orderType = orderType;
    }

    public String getOrderBusinessType() {
        return orderBusinessType;
    }

    public void setOrderBusinessType(String orderBusinessType) {
        this.orderBusinessType = orderBusinessType;
    }

    public String getMemberLevel() {
        return memberLevel;
    }

    public void setMemberLevel(String memberLevel) {
        this.memberLevel = memberLevel;
    }

    public Date getOrderStartDate() {
        return orderStartDate;
    }

    public void setOrderStartDate(Date orderStartDate) {
        this.orderStartDate = orderStartDate;
    }

    public Date getOrderEndDate() {
        return orderEndDate;
    }

    public void setOrderEndDate(Date orderEndDate) {
        this.orderEndDate = orderEndDate;
    }

    public Date getPayStartDate() {
        return payStartDate;
    }

    public void setPayStartDate(Date payStartDate) {
        this.payStartDate = payStartDate;
    }

    public Date getPayEndDate() {
        return payEndDate;
    }

    public void setPayEndDate(Date payEndDate) {
        this.payEndDate = payEndDate;
    }


    public Integer getHasJoin() {
        return hasJoin;
    }

    public void setHasJoin(Integer hasJoin) {
        this.hasJoin = hasJoin;
    }


    public String getGiftQualification() {
        return giftQualification;
    }

    public void setGiftQualification(String giftQualification) {
        this.giftQualification = giftQualification;
    }

    public String getThirdPartyInterface() {
        return thirdPartyInterface;
    }

    public void setThirdPartyInterface(String thirdPartyInterface) {
        this.thirdPartyInterface = thirdPartyInterface;
    }

    public String getOrderRemark() {
        return orderRemark;
    }

    public void setOrderRemark(String orderRemark) {
        this.orderRemark = orderRemark;
    }

    public Boolean getIsFuzzyMatch() {
        return isFuzzyMatch;
    }

    public void setIsFuzzyMatch(Boolean isFuzzyMatch) {
        this.isFuzzyMatch = isFuzzyMatch;
    }

    public Integer getScope() {
        return scope;
    }

    public void setScope(Integer scope) {
        this.scope = scope;
    }

    public Integer getGiftWay() {
        return giftWay;
    }

    public void setGiftWay(Integer giftWay) {
        this.giftWay = giftWay;
    }

    public Integer getRandomNum() {
        return randomNum;
    }

    public void setRandomNum(Integer randomNum) {
        this.randomNum = randomNum;
    }

    public Integer getTotalNum() {
        return totalNum;
    }

    public void setTotalNum(Integer totalNum) {
        this.totalNum = totalNum;
    }

    public Integer getSingleLimit() {
        return singleLimit;
    }

    public void setSingleLimit(Integer singleLimit) {
        this.singleLimit = singleLimit;
    }

    public Integer getGiftCondition() {
        return giftCondition;
    }

    public void setGiftCondition(Integer giftCondition) {
        this.giftCondition = giftCondition;
    }

    public Integer getStepRule() {
        return stepRule;
    }

    public void setStepRule(Integer stepRule) {
        this.stepRule = stepRule;
    }

    public Integer getCreateUserId() {
        return createUserId;
    }

    public void setCreateUserId(Integer createUserId) {
        this.createUserId = createUserId;
    }

    public String getCreateUserName() {
        return createUserName;
    }

    public void setCreateUserName(String createUserName) {
        this.createUserName = createUserName;
    }

    public Date getCreateTime() {
        return createTime;
    }

    public void setCreateTime(Date createTime) {
        this.createTime = createTime;
    }

    public Date getUpdateTime() {
        return updateTime;
    }

    public void setUpdateTime(Date updateTime) {
        this.updateTime = updateTime;
    }

    public List<GiftCampaignConditionSkuVO> getIncludeSkuCodes() {
        return includeSkuCodes;
    }

    public void setIncludeSkuCodes(List<GiftCampaignConditionSkuVO> includeSkuCodes) {
        this.includeSkuCodes = includeSkuCodes;
    }

    public List<GiftCampaignConditionSkuVO> getExcludeSkuCodes() {
        return excludeSkuCodes;
    }

    public void setExcludeSkuCodes(List<GiftCampaignConditionSkuVO> excludeSkuCodes) {
        this.excludeSkuCodes = excludeSkuCodes;
    }

    public List<Integer> getGiftQualificationIds() {
        return giftQualificationIds;
    }

    public void setGiftQualificationIds(List<Integer> giftQualificationIds) {
        this.giftQualificationIds = giftQualificationIds;
    }

    public List<GiftCampaignQualificationVO> getGiftCampaignQualificationVOList() {
        return giftCampaignQualificationVOList;
    }

    public void setGiftCampaignQualificationVOList(List<GiftCampaignQualificationVO> giftCampaignQualificationVOList) {
        this.giftCampaignQualificationVOList = giftCampaignQualificationVOList;
    }

    public List<GiftCampaignRuleSkuVO> getGiftCampaignRuleSkuVOList() {
        return giftCampaignRuleSkuVOList;
    }

    public void setGiftCampaignRuleSkuVOList(List<GiftCampaignRuleSkuVO> giftCampaignRuleSkuVOList) {
        this.giftCampaignRuleSkuVOList = giftCampaignRuleSkuVOList;
    }

    public String getGiftWayText() {
        return giftWayText;
    }

    public void setGiftWayText(String giftWayText) {
        this.giftWayText = giftWayText;
    }

    public Integer getSendFinishStop() {
        return sendFinishStop;
    }

    public void setSendFinishStop(Integer sendFinishStop) {
        this.sendFinishStop = sendFinishStop;
    }

    public Integer getStepAmountCompute() {
        return stepAmountCompute;
    }

    public void setStepAmountCompute(Integer stepAmountCompute) {
        this.stepAmountCompute = stepAmountCompute;
    }

    public String getOtherCondition() {
        return otherCondition;
    }

    public void setOtherCondition(String otherCondition) {
        this.otherCondition = otherCondition;
    }

    public String getSpecialCondition() {
        return specialCondition;
    }

    public void setSpecialCondition(String specialCondition) {
        this.specialCondition = specialCondition;
    }
}
